<?php
/*
Plugin Name: Page Styler
Plugin URI: http://pixopoint.com/
Description: For changing the background colour of your Twenty Eleven based theme
Version: 1.0
Author: Ryan Hellyer
Author URI: http://pixopoint.com/


Todo: Add POT file for translations


------------------------------------------------------------------------
Copyright Ryan Hellyer

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/


/**
 * Bail out now if current version of Twenty Eleven not present
 *
 * @since 1.0
 * @author Ryan Hellyer <ryan@pixopoint.com>
 */
function pagestyler_admin_notice(){
	if ( !function_exists( 'twentyeleven_customize_register' ) ) {
		echo '
		<div class="error">
			<p>This plugin requires the Twenty Eleven theme version 1.3 or newer to function.</p>
		</div>';
	}
}
add_action('admin_notices', 'pagestyler_admin_notice');

/**
 * Register the form setting for our twentyeleven_options array.
 *
 * @since 1.0
 * @author Ryan Hellyer <ryan@pixopoint.com>
 */
function pagestyler_options_init() {
	add_settings_field(
		'page_color',
		__( 'Page Color',  'page_styling' ),
		'twentyeleven_settings_field_page_color',
		'theme_options',
		'general'
	);
}
add_action( 'admin_init', 'pagestyler_options_init' );

/**
 * Sanitize the colour selection
 *
 * @since 1.0
 * @author Ryan Hellyer <ryan@pixopoint.com>
 * @param  array   $output  The sanitized data output
 * @param  array   $input   The unsanitized data input
 * @return array
 */
function pagestyler_validate( $output, $input ) {

	// Link color must be 3 or 6 hexadecimal characters
	if ( isset( $input['page_color'] ) && preg_match( '/^#?([a-f0-9]{3}){1,2}$/i', $input['page_color'] ) )
		$output['page_color'] = '#' . strtolower( ltrim( $input['page_color'], '#' ) );

	return $output;
}
add_filter( 'twentyeleven_theme_options_validate', 'pagestyler_validate', '', 2 );

/**
 * Add a style block to the theme for the current page color.
 *
 * @since 1.0
 * @author Ryan Hellyer <ryan@pixopoint.com>
 */
function pagestyler_print_page_color_style() {
	$options = twentyeleven_get_theme_options();
	$page_color = $options['page_color'];

	?>
	<style>
		/* Page colour */
		#page {
			background-color: <?php echo $page_color; ?>;
		}
	</style>
<?php
}
add_action( 'wp_head', 'pagestyler_print_page_color_style' );

/**
 * Implements Page Styler theme options into Theme Customizer
 *
 * @param $wp_customize Theme Customizer object
 * @since 1.0
 * @author Ryan Hellyer <ryan@pixopoint.com>
 */
function pagestyler_customize_register( $wp_customize ) {

	$options  = twentyeleven_get_theme_options();

	// Link Color (added to Color Scheme section in Theme Customizer)
	$wp_customize->add_setting( 'twentyeleven_theme_options[page_color]', array(
		'default'           => '#fff',
		'type'              => 'option',
		'sanitize_callback' => 'sanitize_hex_color',
		'capability'        => 'edit_theme_options',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_color', array(
		'label'    => __( 'Page Color', 'pagestyler' ),
		'section'  => 'colors',
		'settings' => 'twentyeleven_theme_options[page_color]',
	) ) );

}
add_action( 'customize_register', 'pagestyler_customize_register' );
